==> haskell-base-unicode-symbols-0.2.2.4-8-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-base-unicode-symbols.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: base-unicode-symbols
version: 0.2.2.4
id: base-unicode-symbols-0.2.2.4-EVQwyImcqDC4SRP9GaTcIi
key: base-unicode-symbols-0.2.2.4-EVQwyImcqDC4SRP9GaTcIi
license: BSD-3-Clause
copyright: 2009–2011 Roel van Dijk <vandijk.roel@gmail.com>
maintainer: Roel van Dijk <vandijk.roel@gmail.com>
author: Roel van Dijk <vandijk.roel@gmail.com>
stability: provisional
homepage: http://haskell.org/haskellwiki/Unicode-symbols
synopsis: Unicode alternatives for common functions and operators
description:
    This package defines new symbols for a number of functions,
    operators and types in the base package.
    .
    All symbols are documented with their actual definition and
    information regarding their Unicode code point. They should be
    completely interchangeable with their definitions.
    .
    For further Unicode goodness you can enable the @UnicodeSyntax@
    language extension \[1\]. This extension enables Unicode characters
    to be used to stand for certain ASCII character sequences,
    i.e. &#x2192; instead of @->@, &#x2200; instead of @forall@ and many
    others.
    .
    Original idea by P&#xE9;ter Divi&#xE1;nszky.
    .
    \[1\] <http://www.haskell.org/ghc/docs/latest/html/users_guide/syntax-extns.html#unicode-syntax>
abi: 317c5ffff2937e1007e568a75e4649c6
exposed: True
exposed-modules:
    Control.Applicative.Unicode Control.Arrow.Unicode
    Control.Category.Unicode Control.Monad.Unicode Data.Bool.Unicode
    Data.Eq.Unicode Data.Foldable.Unicode Data.Function.Unicode
    Data.List.Unicode Data.Monoid.Unicode Data.Ord.Unicode
    Prelude.Unicode
import-dirs: /usr/lib/ghc-8.4.3/site-local/base-unicode-symbols-0.2.2.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/base-unicode-symbols-0.2.2.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/base-unicode-symbols-0.2.2.4
hs-libraries: HSbase-unicode-symbols-0.2.2.4-EVQwyImcqDC4SRP9GaTcIi
depends:
    base-4.11.1.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
haddock-interfaces: /usr/share/doc/haskell-base-unicode-symbols/html/base-unicode-symbols.haddock
haddock-html: /usr/share/doc/haskell-base-unicode-symbols/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-base-unicode-symbols-0.2.2.4-9-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-base-unicode-symbols.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: base-unicode-symbols
version: 0.2.2.4
id: base-unicode-symbols-0.2.2.4-A4I8mYzRSE3gt3LBeWhol
key: base-unicode-symbols-0.2.2.4-A4I8mYzRSE3gt3LBeWhol
license: BSD-3-Clause
copyright: 2009–2011 Roel van Dijk <vandijk.roel@gmail.com>
maintainer: Roel van Dijk <vandijk.roel@gmail.com>
author: Roel van Dijk <vandijk.roel@gmail.com>
stability: provisional
homepage: http://haskell.org/haskellwiki/Unicode-symbols
synopsis: Unicode alternatives for common functions and operators
description:
    This package defines new symbols for a number of functions,
    operators and types in the base package.
    .
    All symbols are documented with their actual definition and
    information regarding their Unicode code point. They should be
    completely interchangeable with their definitions.
    .
    For further Unicode goodness you can enable the @UnicodeSyntax@
    language extension \[1\]. This extension enables Unicode characters
    to be used to stand for certain ASCII character sequences,
    i.e. &#x2192; instead of @->@, &#x2200; instead of @forall@ and many
    others.
    .
    Original idea by P&#xE9;ter Divi&#xE1;nszky.
    .
    \[1\] <http://www.haskell.org/ghc/docs/latest/html/users_guide/syntax-extns.html#unicode-syntax>
abi: 9c3c0f555073e56b353172294537dda8
exposed: True
exposed-modules:
    Control.Applicative.Unicode Control.Arrow.Unicode
    Control.Category.Unicode Control.Monad.Unicode Data.Bool.Unicode
    Data.Eq.Unicode Data.Foldable.Unicode Data.Function.Unicode
    Data.List.Unicode Data.Monoid.Unicode Data.Ord.Unicode
    Prelude.Unicode
import-dirs: /usr/lib/ghc-8.6.1/site-local/base-unicode-symbols-0.2.2.4
library-dirs: /usr/lib/ghc-8.6.1/site-local/base-unicode-symbols-0.2.2.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/base-unicode-symbols-0.2.2.4
hs-libraries: HSbase-unicode-symbols-0.2.2.4-A4I8mYzRSE3gt3LBeWhol
depends:
    base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-base-unicode-symbols/html/base-unicode-symbols.haddock
haddock-html: /usr/share/doc/haskell-base-unicode-symbols/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
